@@ -615,6 +615,23 @@ def view_progress_compute(request: HttpRequest, year: int | str | None = None) -
     return redirect("orgapy:progress_year", year=counter.year)
 
 
+@permission_required("orgapy.view_progress")
+def view_progress_export(request: HttpRequest, year: int | str | None = None) -> HttpResponse:
+    if year is None:
+        year = datetime.datetime.now().year
+    else:
+        year = int(year)
+    lines = ["id\ttype\tdt\tdescription"]
+    for log in ProgressLog.objects.filter(user=request.user, dt__year=year):
+        lines.append("\t".join([
+            str(log.id),
+            log.type,
+            log.dt.isoformat(),
+            str(log.description)
+        ]))
+    return HttpResponse("\n".join(lines), content_type="text/tab-separated-values")
+
+
 @permission_required("orgapy.add_progress_log")
 def view_create_progress_log(request: HttpRequest) -> HttpResponse:
     return render(request, "orgapy/create_progress_log.html", {})
